@@ -288,7 +288,7 @@ class HardwareTests(testing.TestCase):
         ex = self.assertRaises(SoftLayer.SoftLayerError,
                                self.hardware.cancel_hardware,
                                6327)
-        self.assertEqual("Ticket #1234 already exists for this server",  str(ex))
+        self.assertEqual("Ticket #1234 already exists for this server", str(ex))
 
     def test_cancel_hardware_monthly_now(self):
         mock = self.set_mock('SoftLayer_Hardware_Server', 'getObject')
@@ -392,6 +392,24 @@ class HardwareTests(testing.TestCase):
                                 'createFirmwareUpdateTransaction',
                                 identifier=100, args=(0, 1, 1, 0))
 
+    def test_reflash_firmware(self):
+        result = self.hardware.reflash_firmware(100)
+
+        self.assertEqual(result, True)
+        self.assert_called_with('SoftLayer_Hardware_Server',
+                                'createFirmwareReflashTransaction',
+                                identifier=100, args=(1, 1, 1))
+
+    def test_reflash_firmware_selective(self):
+        result = self.hardware.reflash_firmware(100,
+                                                raid_controller=False,
+                                                bios=False)
+
+        self.assertEqual(result, True)
+        self.assert_called_with('SoftLayer_Hardware_Server',
+                                'createFirmwareReflashTransaction',
+                                identifier=100, args=(1, 0, 0))
+
 
 class HardwareHelperTests(testing.TestCase):
     def test_get_extra_price_id_no_items(self):
